@@ -254,6 +254,31 @@ class BaseBarHelper:
 
         return lst_all_date_time_slices
 
+    @staticmethod
+    def create_in_day_date_time_slice_by_date_24h(begin_date, end_date, interval, bar_type):
+        """
+        根据日期区间创建日内的日期时间片段 24小时交易的
+        :param begin_date:开始时间
+        :param end_date:截止时间
+        :param interval:间隔
+        :param bar_type:K线类型
+        :return:
+        """
+        lst_all_date_time_slices = []
+        begin_trading_date = TradingDayHelper.get_first_trading_day(begin_date)
+        end_trading_day = TradingDayHelper.get_last_trading_day(end_date)
+        lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_day)
+        for trading_day in lst_trading_days:
+            time_slice = TimeSlice(begin_time=datetime.timedelta(hours=0, minutes=0, seconds=0), end_time=datetime.timedelta(hours=23, minutes=59, seconds=59))
+            lst_trading_time_slices = [time_slice]
+            lst_time_slices = BaseBarHelper.create_time_slice(lst_trading_time_slices, 0, interval, bar_type)
+            lst_date_time_slices = BaseBarHelper.create_date_time_slice(trading_day, lst_time_slices)
+            for dateTimeSlice in lst_date_time_slices:
+                lst_all_date_time_slices.append(dateTimeSlice)
+
+        return lst_all_date_time_slices
+
+
     @staticmethod
     def create_in_day_date_time_slice_by_date_consider_holiday(instrument_manager, instrument_id, begin_date, end_date, interval, bar_type, *instrument_ids):
         """
